@@ -2,7 +2,7 @@
     MidiLearn.cpp
 
     Copyright 2016-2020, Will Godfrey
-    Copyright 2021, Will Godfrey, Rainer Hans Liffers
+    Copyright 2021-2023, Will Godfrey, Rainer Hans Liffers
 
     This file is part of yoshimi, which is free software: you can redistribute
     it and/or modify it under the terms of the GNU General Public
@@ -20,12 +20,12 @@
 
 */
 
-const int fromString = 1;
+const int fromText = 1;
 /*
- * 0 = use numbers
- * 1 = use string
- * 2 = use numbers report diff
- * 3 = use string report diff
+ * 0 = use legacy numbers
+ * 1 = decode from text
+ * 2 = use legacy numbers report difference
+ * 3 = decode from text report difference
  */
 
 #include "Interface/MidiLearn.h"
@@ -989,6 +989,7 @@ bool MidiLearn::extractMidiListData(bool full,  XMLwrapper *xml)
         return false;
     }
     LearnBlock entry;
+    CommandBlock allData;
     midi_list.clear();
     int ID = 0;
     int status;
@@ -1037,13 +1038,13 @@ bool MidiLearn::extractMidiListData(bool full,  XMLwrapper *xml)
                 entry.frame.data.parameter = xml->getpar255("Parameter", 0);
                 entry.frame.data.offset = xml->getpar255("Secondary_Parameter", 0);
 
-                CommandBlock allData;
-if (fromString)
+if (fromText)
 {
                 string test = xml->getparstr("Command_Name");
                 TextData::encodeAll(synth, test, allData);
+                //synth->CBtest(&allData);
 }
-if (fromString & 2)
+if (fromText >= 2)
 {
                 bool ok = true;
                 if (ID == 0)
@@ -1090,7 +1091,7 @@ if (fromString & 2)
                 }
                 cout << endl;
 }
-if (fromString == 3)
+if (fromText & 1)
 {
                 entry.frame.data.control = allData.data.control;
                 entry.frame.data.part = allData.data.part;
@@ -1108,6 +1109,6 @@ if (fromString == 3)
         }
     }
     xml->exitbranch(); // MIDILEARN
+    //synth->CBtest(&allData);
     return true;
 }
-
