@@ -4,10 +4,10 @@
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
     Copyright 2009-2011, Alan Calvert
-    Copyright 2017-2019, Will Godfrey
+    Copyright 2017-2021, Will Godfrey
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of the GNU Library General Public
+    it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation; either version 2 of
     the License, or (at your option) any later version.
 
@@ -21,8 +21,6 @@
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
     This file is derivative of original ZynAddSubFX code.
-
-    Modified May 2019
 */
 
 #include <cmath>
@@ -34,9 +32,11 @@
 #include "Misc/XMLwrapper.h"
 #include "Misc/Microtonal.h"
 #include "Misc/SynthEngine.h"
+#include "Misc/NumericFuncs.h"
 #include "Misc/FormatFuncs.h"
 #include "Misc/FileMgrFuncs.h"
 
+using func::power;
 using file::loadText;
 using file::findLeafName;
 using std::cout;
@@ -135,7 +135,7 @@ float Microtonal::getNoteFreq(int note, int keyshift)
     // compute global fine detune, -64.0 .. 63.0 cents
     float globalfinedetunerap =
         (Pglobalfinedetune > 64.0f || Pglobalfinedetune < 64.0f)
-            ? powf(2.0f, (Pglobalfinedetune - 64.0f) / 1200.0f)
+            ? power<2>((Pglobalfinedetune - 64.0f) / 1200.0f)
             : 1.0f;
     // was float globalfinedetunerap = powf(2.0f, (Pglobalfinedetune - 64.0f) / 1200.0f);
 
@@ -175,7 +175,7 @@ float Microtonal::getNoteFreq(int note, int keyshift)
                 deltanote++;
         float rap_anote_middlenote =
             (deltanote == 0) ? (1.0f) : (octave[(deltanote - 1) % octavesize].tuning);
-        if(deltanote != 0)
+        if (deltanote != 0)
             rap_anote_middlenote *= powf(octave[octavesize - 1].tuning,
                                          (deltanote - 1) / octavesize);
         if (minus)
@@ -227,7 +227,7 @@ float Microtonal::getNoteFreq(int note, int keyshift)
 
 string Microtonal::reformatline(string text)
 {
-    text.erase(remove_if( text.begin(), text.end(),
+    text.erase(remove_if (text.begin(), text.end(),
      [](char c){ return (c =='\r' || c =='\t' || c == ' ' || c == '\n');}), text.end() );
 
     size_t found;
@@ -238,7 +238,7 @@ string Microtonal::reformatline(string text)
         text = tmp + text;
     }
     found = text.size();
-    if ( found < 11)
+    if (found < 11)
     {
         string tmp  (11 - found, '0'); // trailing zeros
         text += tmp;
@@ -316,7 +316,7 @@ int Microtonal::linetotunings(unsigned int nline, const char *line)
             break;
     }
 
-    tmpoctave[nline].text = reformatline(string(line));
+    tmpoctave[nline].text = reformatline(line);
     tmpoctave[nline].tuning = tuning;
     tmpoctave[nline].type = type;
     tmpoctave[nline].x1 = x1;
@@ -467,20 +467,20 @@ string Microtonal::tuningtotext()
 }
 
 
-int Microtonal::loadLine(string text, size_t &point, char *line, size_t maxlen)
+int Microtonal::loadLine(const string& text, size_t &point, char *line, size_t maxlen)
 {
     do {
         line[0] = 0;
         C_lineInText(text, point, line, maxlen);
-        if (line[0] == 0)
-            return -5;
     } while (line[0] == '!');
+    if (line[0] < ' ')
+        return -5;
     return 0;
 }
 
 
 // Loads the tunings from a scl file
-int Microtonal::loadscl(string filename)
+int Microtonal::loadscl(const string& filename)
 {
     string text = loadText(filename);
     if (text == "")
@@ -529,12 +529,13 @@ int Microtonal::loadscl(string filename)
     octavesize = nnotes;
     std::swap(octave, tmpoctave);
     synth->setAllPartMaps();
+    synth->addHistory(filename, TOPLEVEL::XML::ScalaTune);
     return nnotes;
 }
 
 
 // Loads the mapping from a kbm file
-int Microtonal::loadkbm(string filename)
+int Microtonal::loadkbm(const string& filename)
 {
     string text = loadText(filename);
     if (text == "")
@@ -582,7 +583,7 @@ int Microtonal::loadkbm(string filename)
     int tmpMid;
     if (err == 0)
     {
-        // loads the middle note where scale fro scale degree=0
+        // loads the middle note where scale from scale degree=0
        if (loadLine(text, point, tmp, BUFFSIZ))
             err = -5;
         else if (!sscanf(&tmp[0], "%d", &tmpMid))
@@ -653,6 +654,7 @@ int Microtonal::loadkbm(string filename)
     PrefNote = tmpNote;
     PrefFreq = tmpPrefFreq;
     synth->setAllPartMaps();
+    synth->addHistory(filename, TOPLEVEL::XML::ScalaMap);
     return tmpMapSize;
 }
 
@@ -666,7 +668,7 @@ void Microtonal::add2XML(XMLwrapper *xml)
     xml->addpar("invert_up_down_center", Pinvertupdowncenter);
 
     xml->addparbool("enabled", Penabled);
-    xml->addpar("global_fine_detune", lrint(Pglobalfinedetune));
+    xml->addparcombi("global_fine_detune", Pglobalfinedetune);
 
     xml->addpar("a_note", PrefNote);
     xml->addparreal("a_freq", PrefFreq);
@@ -726,7 +728,7 @@ void Microtonal::getfromXML(XMLwrapper *xml)
     Pinvertupdowncenter=xml->getpar127("invert_up_down_center", Pinvertupdowncenter);
 
     Penabled=xml->getparbool("enabled", Penabled);
-    Pglobalfinedetune = xml->getpar127("global_fine_detune", Pglobalfinedetune);
+    Pglobalfinedetune = xml->getparcombi("global_fine_detune", Pglobalfinedetune, 0, 127);
 
     PrefNote = xml->getpar127("a_note", PrefNote);
     PrefFreq = xml->getparreal("a_freq", PrefFreq, 1.0, 10000.0);
@@ -795,7 +797,7 @@ void Microtonal::getfromXML(XMLwrapper *xml)
 }
 
 
-bool Microtonal::saveXML(string filename)
+bool Microtonal::saveXML(const string& filename)
 {
     synth->getRuntime().xmlType = TOPLEVEL::XML::Scale;
     XMLwrapper *xml = new XMLwrapper(synth);
@@ -810,12 +812,12 @@ bool Microtonal::saveXML(string filename)
 }
 
 
-bool Microtonal::loadXML(string filename)
+bool Microtonal::loadXML(const string& filename)
 {
     XMLwrapper *xml = new XMLwrapper(synth);
     if (NULL == xml)
     {
-        synth->getRuntime().Log("Microtonal: loadXML failed to instantiate new XMLwrapper", 1);
+        synth->getRuntime().Log("Microtonal: loadXML failed to instantiate new XMLwrapper", _SYS_::LogError);
         return false;
     }
     if (!xml->loadXMLfile(filename))
@@ -825,7 +827,7 @@ bool Microtonal::loadXML(string filename)
     }
     if (!xml->enterbranch("MICROTONAL"))
     {
-        synth->getRuntime().Log(filename + " is not a scale file", 1);
+        synth->getRuntime().Log(filename + " is not a scale file", _SYS_::LogError);
         delete xml;
         return false;
     }
@@ -838,7 +840,7 @@ bool Microtonal::loadXML(string filename)
 
 float Microtonal::getLimits(CommandBlock *getData)
 {
-    float value = getData->data.value.F;
+    float value = getData->data.value;
     int request = int(getData->data.type & TOPLEVEL::type::Default);
     int control = getData->data.control;
 
@@ -935,9 +937,9 @@ float Microtonal::getLimits(CommandBlock *getData)
     switch (request)
     {
         case TOPLEVEL::type::Adjust:
-            if(value < min)
+            if (value < min)
                 value = min;
-            else if(value > max)
+            else if (value > max)
                 value = max;
         break;
         case TOPLEVEL::type::Minimum:
